===========
ingredients
===========


.. image:: https://img.shields.io/pypi/v/ingredients.svg
        :target: https://pypi.python.org/pypi/ingredients

.. image:: https://img.shields.io/travis/kyoungrok0517/ingredients.svg
        :target: https://travis-ci.org/kyoungrok0517/ingredients

.. image:: https://readthedocs.org/projects/ingredients/badge/?version=latest
        :target: https://ingredients.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/kyoungrok0517/ingredients/shield.svg
     :target: https://pyup.io/repos/github/kyoungrok0517/ingredients/
     :alt: Updates



ingredients code for practicing python packaging


* Free software: MIT license
* Documentation: https://ingredients.readthedocs.io.


Features
--------

* This text is added for practice.
* Added to test `servedocs`.
* Final test.

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
